@@ -1,8 +1,10 @@
+from http import HTTPStatus
 from typing import Any, Dict, Optional, Union
 
 import httpx
 
-from ...client import Client
+from ... import errors
+from ...client import AuthenticatedClient, Client
 from ...models.get_job_updates_response_200 import GetJobUpdatesResponse200
 from ...types import UNSET, Response, Unset
 
@@ -11,14 +13,10 @@ def _get_kwargs(
     workspace: str,
     id: str,
     *,
-    client: Client,
     running: Union[Unset, None, bool] = UNSET,
     log_offset: Union[Unset, None, int] = UNSET,
 ) -> Dict[str, Any]:
-    url = "{}/w/{workspace}/jobs_u/getupdate/{id}".format(client.base_url, workspace=workspace, id=id)
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
+    pass
 
     params: Dict[str, Any] = {}
     params["running"] = running
@@ -29,28 +27,35 @@ def _get_kwargs(
 
     return {
         "method": "get",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
+        "url": "/w/{workspace}/jobs_u/getupdate/{id}".format(
+            workspace=workspace,
+            id=id,
+        ),
         "params": params,
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[GetJobUpdatesResponse200]:
-    if response.status_code == 200:
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[GetJobUpdatesResponse200]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = GetJobUpdatesResponse200.from_dict(response.json())
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(response.status_code, response.content)
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[GetJobUpdatesResponse200]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[GetJobUpdatesResponse200]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -58,7 +63,7 @@ def sync_detailed(
     workspace: str,
     id: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     running: Union[Unset, None, bool] = UNSET,
     log_offset: Union[Unset, None, int] = UNSET,
 ) -> Response[GetJobUpdatesResponse200]:
@@ -70,6 +75,10 @@ def sync_detailed(
         running (Union[Unset, None, bool]):
         log_offset (Union[Unset, None, int]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[GetJobUpdatesResponse200]
     """
@@ -77,24 +86,22 @@ def sync_detailed(
     kwargs = _get_kwargs(
         workspace=workspace,
         id=id,
-        client=client,
         running=running,
         log_offset=log_offset,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
     workspace: str,
     id: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     running: Union[Unset, None, bool] = UNSET,
     log_offset: Union[Unset, None, int] = UNSET,
 ) -> Optional[GetJobUpdatesResponse200]:
@@ -106,8 +113,12 @@ def sync(
         running (Union[Unset, None, bool]):
         log_offset (Union[Unset, None, int]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[GetJobUpdatesResponse200]
+        GetJobUpdatesResponse200
     """
 
     return sync_detailed(
@@ -123,7 +134,7 @@ async def asyncio_detailed(
     workspace: str,
     id: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     running: Union[Unset, None, bool] = UNSET,
     log_offset: Union[Unset, None, int] = UNSET,
 ) -> Response[GetJobUpdatesResponse200]:
@@ -135,6 +146,10 @@ async def asyncio_detailed(
         running (Union[Unset, None, bool]):
         log_offset (Union[Unset, None, int]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[GetJobUpdatesResponse200]
     """
@@ -142,22 +157,20 @@ async def asyncio_detailed(
     kwargs = _get_kwargs(
         workspace=workspace,
         id=id,
-        client=client,
         running=running,
         log_offset=log_offset,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
     workspace: str,
     id: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     running: Union[Unset, None, bool] = UNSET,
     log_offset: Union[Unset, None, int] = UNSET,
 ) -> Optional[GetJobUpdatesResponse200]:
@@ -169,8 +182,12 @@ async def asyncio(
         running (Union[Unset, None, bool]):
         log_offset (Union[Unset, None, int]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[GetJobUpdatesResponse200]
+        GetJobUpdatesResponse200
     """
 
     return (
