@@ -1,9 +1,11 @@
 import datetime
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional, Union
 
 import httpx
 
-from ...client import Client
+from ... import errors
+from ...client import AuthenticatedClient, Client
 from ...models.list_jobs_response_200_item import ListJobsResponse200Item
 from ...types import UNSET, Response, Unset
 
@@ -11,7 +13,6 @@ from ...types import UNSET, Response, Unset
 def _get_kwargs(
     workspace: str,
     *,
-    client: Client,
     created_by: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
@@ -20,6 +21,9 @@ def _get_kwargs(
     script_hash: Union[Unset, None, str] = UNSET,
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
+    running: Union[Unset, None, bool] = UNSET,
+    created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
@@ -28,10 +32,7 @@ def _get_kwargs(
     is_flow_step: Union[Unset, None, bool] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
-    url = "{}/w/{workspace}/jobs/list".format(client.base_url, workspace=workspace)
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
+    pass
 
     params: Dict[str, Any] = {}
     params["created_by"] = created_by
@@ -58,6 +59,20 @@ def _get_kwargs(
 
     params["started_after"] = json_started_after
 
+    json_created_or_started_before: Union[Unset, None, str] = UNSET
+    if not isinstance(created_or_started_before, Unset):
+        json_created_or_started_before = created_or_started_before.isoformat() if created_or_started_before else None
+
+    params["created_or_started_before"] = json_created_or_started_before
+
+    params["running"] = running
+
+    json_created_or_started_after: Union[Unset, None, str] = UNSET
+    if not isinstance(created_or_started_after, Unset):
+        json_created_or_started_after = created_or_started_after.isoformat() if created_or_started_after else None
+
+    params["created_or_started_after"] = json_created_or_started_after
+
     params["job_kinds"] = job_kinds
 
     params["args"] = args
@@ -76,16 +91,17 @@ def _get_kwargs(
 
     return {
         "method": "get",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
+        "url": "/w/{workspace}/jobs/list".format(
+            workspace=workspace,
+        ),
         "params": params,
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[List[ListJobsResponse200Item]]:
-    if response.status_code == 200:
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[List["ListJobsResponse200Item"]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = []
         _response_200 = response.json()
         for response_200_item_data in _response_200:
@@ -94,22 +110,27 @@ def _parse_response(*, response: httpx.Response) -> Optional[List[ListJobsRespon
             response_200.append(response_200_item)
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(response.status_code, response.content)
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[List[ListJobsResponse200Item]]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[List["ListJobsResponse200Item"]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
 def sync_detailed(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     created_by: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
@@ -118,6 +139,9 @@ def sync_detailed(
     script_hash: Union[Unset, None, str] = UNSET,
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
+    running: Union[Unset, None, bool] = UNSET,
+    created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
@@ -125,8 +149,8 @@ def sync_detailed(
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
-) -> Response[List[ListJobsResponse200Item]]:
-    """list all available jobs
+) -> Response[List["ListJobsResponse200Item"]]:
+    """list all jobs
 
     Args:
         workspace (str):
@@ -138,6 +162,9 @@ def sync_detailed(
         script_hash (Union[Unset, None, str]):
         started_before (Union[Unset, None, datetime.datetime]):
         started_after (Union[Unset, None, datetime.datetime]):
+        created_or_started_before (Union[Unset, None, datetime.datetime]):
+        running (Union[Unset, None, bool]):
+        created_or_started_after (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
         args (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
@@ -146,13 +173,16 @@ def sync_detailed(
         is_flow_step (Union[Unset, None, bool]):
         success (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListJobsResponse200Item]]
+        Response[List['ListJobsResponse200Item']]
     """
 
     kwargs = _get_kwargs(
         workspace=workspace,
-        client=client,
         created_by=created_by,
         parent_job=parent_job,
         script_path_exact=script_path_exact,
@@ -161,6 +191,9 @@ def sync_detailed(
         script_hash=script_hash,
         started_before=started_before,
         started_after=started_after,
+        created_or_started_before=created_or_started_before,
+        running=running,
+        created_or_started_after=created_or_started_after,
         job_kinds=job_kinds,
         args=args,
         tag=tag,
@@ -170,18 +203,17 @@ def sync_detailed(
         success=success,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     created_by: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
@@ -190,6 +222,9 @@ def sync(
     script_hash: Union[Unset, None, str] = UNSET,
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
+    running: Union[Unset, None, bool] = UNSET,
+    created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
@@ -197,8 +232,8 @@ def sync(
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
-) -> Optional[List[ListJobsResponse200Item]]:
-    """list all available jobs
+) -> Optional[List["ListJobsResponse200Item"]]:
+    """list all jobs
 
     Args:
         workspace (str):
@@ -210,6 +245,9 @@ def sync(
         script_hash (Union[Unset, None, str]):
         started_before (Union[Unset, None, datetime.datetime]):
         started_after (Union[Unset, None, datetime.datetime]):
+        created_or_started_before (Union[Unset, None, datetime.datetime]):
+        running (Union[Unset, None, bool]):
+        created_or_started_after (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
         args (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
@@ -218,8 +256,12 @@ def sync(
         is_flow_step (Union[Unset, None, bool]):
         success (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListJobsResponse200Item]]
+        List['ListJobsResponse200Item']
     """
 
     return sync_detailed(
@@ -233,6 +275,9 @@ def sync(
         script_hash=script_hash,
         started_before=started_before,
         started_after=started_after,
+        created_or_started_before=created_or_started_before,
+        running=running,
+        created_or_started_after=created_or_started_after,
         job_kinds=job_kinds,
         args=args,
         tag=tag,
@@ -246,7 +291,7 @@ def sync(
 async def asyncio_detailed(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     created_by: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
@@ -255,6 +300,9 @@ async def asyncio_detailed(
     script_hash: Union[Unset, None, str] = UNSET,
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
+    running: Union[Unset, None, bool] = UNSET,
+    created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
@@ -262,8 +310,8 @@ async def asyncio_detailed(
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
-) -> Response[List[ListJobsResponse200Item]]:
-    """list all available jobs
+) -> Response[List["ListJobsResponse200Item"]]:
+    """list all jobs
 
     Args:
         workspace (str):
@@ -275,6 +323,9 @@ async def asyncio_detailed(
         script_hash (Union[Unset, None, str]):
         started_before (Union[Unset, None, datetime.datetime]):
         started_after (Union[Unset, None, datetime.datetime]):
+        created_or_started_before (Union[Unset, None, datetime.datetime]):
+        running (Union[Unset, None, bool]):
+        created_or_started_after (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
         args (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
@@ -283,13 +334,16 @@ async def asyncio_detailed(
         is_flow_step (Union[Unset, None, bool]):
         success (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListJobsResponse200Item]]
+        Response[List['ListJobsResponse200Item']]
     """
 
     kwargs = _get_kwargs(
         workspace=workspace,
-        client=client,
         created_by=created_by,
         parent_job=parent_job,
         script_path_exact=script_path_exact,
@@ -298,6 +352,9 @@ async def asyncio_detailed(
         script_hash=script_hash,
         started_before=started_before,
         started_after=started_after,
+        created_or_started_before=created_or_started_before,
+        running=running,
+        created_or_started_after=created_or_started_after,
         job_kinds=job_kinds,
         args=args,
         tag=tag,
@@ -307,16 +364,15 @@ async def asyncio_detailed(
         success=success,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     created_by: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
@@ -325,6 +381,9 @@ async def asyncio(
     script_hash: Union[Unset, None, str] = UNSET,
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
+    running: Union[Unset, None, bool] = UNSET,
+    created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
@@ -332,8 +391,8 @@ async def asyncio(
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
-) -> Optional[List[ListJobsResponse200Item]]:
-    """list all available jobs
+) -> Optional[List["ListJobsResponse200Item"]]:
+    """list all jobs
 
     Args:
         workspace (str):
@@ -345,6 +404,9 @@ async def asyncio(
         script_hash (Union[Unset, None, str]):
         started_before (Union[Unset, None, datetime.datetime]):
         started_after (Union[Unset, None, datetime.datetime]):
+        created_or_started_before (Union[Unset, None, datetime.datetime]):
+        running (Union[Unset, None, bool]):
+        created_or_started_after (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
         args (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
@@ -353,8 +415,12 @@ async def asyncio(
         is_flow_step (Union[Unset, None, bool]):
         success (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListJobsResponse200Item]]
+        List['ListJobsResponse200Item']
     """
 
     return (
@@ -369,6 +435,9 @@ async def asyncio(
             script_hash=script_hash,
             started_before=started_before,
             started_after=started_after,
+            created_or_started_before=created_or_started_before,
+            running=running,
+            created_or_started_after=created_or_started_after,
             job_kinds=job_kinds,
             args=args,
             tag=tag,
