@@ -1,9 +1,11 @@
 import datetime
-from typing import Any, Dict, Union
+from http import HTTPStatus
+from typing import Any, Dict, Optional, Union
 
 import httpx
 
-from ...client import Client
+from ... import errors
+from ...client import AuthenticatedClient, Client
 from ...models.run_script_by_hash_json_body import RunScriptByHashJsonBody
 from ...types import UNSET, Response, Unset
 
@@ -12,7 +14,6 @@ def _get_kwargs(
     workspace: str,
     hash_: str,
     *,
-    client: Client,
     json_body: RunScriptByHashJsonBody,
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
@@ -21,10 +22,7 @@ def _get_kwargs(
     include_header: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
-    url = "{}/w/{workspace}/jobs/run/h/{hash}".format(client.base_url, workspace=workspace, hash=hash_)
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
+    pass
 
     params: Dict[str, Any] = {}
     json_scheduled_for: Union[Unset, None, str] = UNSET
@@ -49,21 +47,28 @@ def _get_kwargs(
 
     return {
         "method": "post",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
+        "url": "/w/{workspace}/jobs/run/h/{hash}".format(
+            workspace=workspace,
+            hash=hash_,
+        ),
         "json": json_json_body,
         "params": params,
     }
 
 
-def _build_response(*, response: httpx.Response) -> Response[Any]:
+def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Any]:
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(response.status_code, response.content)
+    else:
+        return None
+
+
+def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Any]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=None,
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -71,7 +76,7 @@ def sync_detailed(
     workspace: str,
     hash_: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     json_body: RunScriptByHashJsonBody,
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
@@ -93,6 +98,10 @@ def sync_detailed(
         invisible_to_owner (Union[Unset, None, bool]):
         json_body (RunScriptByHashJsonBody):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Any]
     """
@@ -100,7 +109,6 @@ def sync_detailed(
     kwargs = _get_kwargs(
         workspace=workspace,
         hash_=hash_,
-        client=client,
         json_body=json_body,
         scheduled_for=scheduled_for,
         scheduled_in_secs=scheduled_in_secs,
@@ -110,19 +118,18 @@ def sync_detailed(
         invisible_to_owner=invisible_to_owner,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio_detailed(
     workspace: str,
     hash_: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     json_body: RunScriptByHashJsonBody,
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
@@ -144,6 +151,10 @@ async def asyncio_detailed(
         invisible_to_owner (Union[Unset, None, bool]):
         json_body (RunScriptByHashJsonBody):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Any]
     """
@@ -151,7 +162,6 @@ async def asyncio_detailed(
     kwargs = _get_kwargs(
         workspace=workspace,
         hash_=hash_,
-        client=client,
         json_body=json_body,
         scheduled_for=scheduled_for,
         scheduled_in_secs=scheduled_in_secs,
@@ -161,7 +171,6 @@ async def asyncio_detailed(
         invisible_to_owner=invisible_to_owner,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
