@@ -1,8 +1,10 @@
-from typing import Any, Dict, Union
+from http import HTTPStatus
+from typing import Any, Dict, Optional, Union
 
 import httpx
 
-from ...client import Client
+from ... import errors
+from ...client import AuthenticatedClient, Client
 from ...models.run_wait_result_script_by_path_json_body import RunWaitResultScriptByPathJsonBody
 from ...types import UNSET, Response, Unset
 
@@ -11,17 +13,13 @@ def _get_kwargs(
     workspace: str,
     path: str,
     *,
-    client: Client,
     json_body: RunWaitResultScriptByPathJsonBody,
     parent_job: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
     queue_limit: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
-    url = "{}/w/{workspace}/jobs/run_wait_result/p/{path}".format(client.base_url, workspace=workspace, path=path)
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
+    pass
 
     params: Dict[str, Any] = {}
     params["parent_job"] = parent_job
@@ -38,21 +36,30 @@ def _get_kwargs(
 
     return {
         "method": "post",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
+        "url": "/w/{workspace}/jobs/run_wait_result/p/{path}".format(
+            workspace=workspace,
+            path=path,
+        ),
         "json": json_json_body,
         "params": params,
     }
 
 
-def _build_response(*, response: httpx.Response) -> Response[Any]:
+def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Any]:
+    if response.status_code == HTTPStatus.OK:
+        return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(response.status_code, response.content)
+    else:
+        return None
+
+
+def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Any]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=None,
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -60,7 +67,7 @@ def sync_detailed(
     workspace: str,
     path: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     json_body: RunWaitResultScriptByPathJsonBody,
     parent_job: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
@@ -78,6 +85,10 @@ def sync_detailed(
         queue_limit (Union[Unset, None, str]):
         json_body (RunWaitResultScriptByPathJsonBody):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Any]
     """
@@ -85,7 +96,6 @@ def sync_detailed(
     kwargs = _get_kwargs(
         workspace=workspace,
         path=path,
-        client=client,
         json_body=json_body,
         parent_job=parent_job,
         job_id=job_id,
@@ -93,19 +103,18 @@ def sync_detailed(
         queue_limit=queue_limit,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio_detailed(
     workspace: str,
     path: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     json_body: RunWaitResultScriptByPathJsonBody,
     parent_job: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
@@ -123,6 +132,10 @@ async def asyncio_detailed(
         queue_limit (Union[Unset, None, str]):
         json_body (RunWaitResultScriptByPathJsonBody):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Any]
     """
@@ -130,7 +143,6 @@ async def asyncio_detailed(
     kwargs = _get_kwargs(
         workspace=workspace,
         path=path,
-        client=client,
         json_body=json_body,
         parent_job=parent_job,
         job_id=job_id,
@@ -138,7 +150,6 @@ async def asyncio_detailed(
         queue_limit=queue_limit,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
