@@ -1,8 +1,10 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional, Union
 
 import httpx
 
-from ...client import Client
+from ... import errors
+from ...client import AuthenticatedClient, Client
 from ...models.list_resource_response_200_item import ListResourceResponse200Item
 from ...types import UNSET, Response, Unset
 
@@ -10,16 +12,12 @@ from ...types import UNSET, Response, Unset
 def _get_kwargs(
     workspace: str,
     *,
-    client: Client,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     resource_type: Union[Unset, None, str] = UNSET,
     resource_type_exclude: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
-    url = "{}/w/{workspace}/resources/list".format(client.base_url, workspace=workspace)
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
+    pass
 
     params: Dict[str, Any] = {}
     params["page"] = page
@@ -34,16 +32,17 @@ def _get_kwargs(
 
     return {
         "method": "get",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
+        "url": "/w/{workspace}/resources/list".format(
+            workspace=workspace,
+        ),
         "params": params,
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[List[ListResourceResponse200Item]]:
-    if response.status_code == 200:
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[List["ListResourceResponse200Item"]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = []
         _response_200 = response.json()
         for response_200_item_data in _response_200:
@@ -52,27 +51,32 @@ def _parse_response(*, response: httpx.Response) -> Optional[List[ListResourceRe
             response_200.append(response_200_item)
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(response.status_code, response.content)
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[List[ListResourceResponse200Item]]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[List["ListResourceResponse200Item"]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
 def sync_detailed(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     resource_type: Union[Unset, None, str] = UNSET,
     resource_type_exclude: Union[Unset, None, str] = UNSET,
-) -> Response[List[ListResourceResponse200Item]]:
+) -> Response[List["ListResourceResponse200Item"]]:
     """list resources
 
     Args:
@@ -82,36 +86,38 @@ def sync_detailed(
         resource_type (Union[Unset, None, str]):
         resource_type_exclude (Union[Unset, None, str]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListResourceResponse200Item]]
+        Response[List['ListResourceResponse200Item']]
     """
 
     kwargs = _get_kwargs(
         workspace=workspace,
-        client=client,
         page=page,
         per_page=per_page,
         resource_type=resource_type,
         resource_type_exclude=resource_type_exclude,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     resource_type: Union[Unset, None, str] = UNSET,
     resource_type_exclude: Union[Unset, None, str] = UNSET,
-) -> Optional[List[ListResourceResponse200Item]]:
+) -> Optional[List["ListResourceResponse200Item"]]:
     """list resources
 
     Args:
@@ -121,8 +127,12 @@ def sync(
         resource_type (Union[Unset, None, str]):
         resource_type_exclude (Union[Unset, None, str]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListResourceResponse200Item]]
+        List['ListResourceResponse200Item']
     """
 
     return sync_detailed(
@@ -138,12 +148,12 @@ def sync(
 async def asyncio_detailed(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     resource_type: Union[Unset, None, str] = UNSET,
     resource_type_exclude: Union[Unset, None, str] = UNSET,
-) -> Response[List[ListResourceResponse200Item]]:
+) -> Response[List["ListResourceResponse200Item"]]:
     """list resources
 
     Args:
@@ -153,34 +163,36 @@ async def asyncio_detailed(
         resource_type (Union[Unset, None, str]):
         resource_type_exclude (Union[Unset, None, str]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListResourceResponse200Item]]
+        Response[List['ListResourceResponse200Item']]
     """
 
     kwargs = _get_kwargs(
         workspace=workspace,
-        client=client,
         page=page,
         per_page=per_page,
         resource_type=resource_type,
         resource_type_exclude=resource_type_exclude,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     resource_type: Union[Unset, None, str] = UNSET,
     resource_type_exclude: Union[Unset, None, str] = UNSET,
-) -> Optional[List[ListResourceResponse200Item]]:
+) -> Optional[List["ListResourceResponse200Item"]]:
     """list resources
 
     Args:
@@ -190,8 +202,12 @@ async def asyncio(
         resource_type (Union[Unset, None, str]):
         resource_type_exclude (Union[Unset, None, str]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListResourceResponse200Item]]
+        List['ListResourceResponse200Item']
     """
 
     return (
