@@ -1,8 +1,10 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional, Union
 
 import httpx
 
-from ...client import Client
+from ... import errors
+from ...client import AuthenticatedClient, Client
 from ...models.list_scripts_response_200_item import ListScriptsResponse200Item
 from ...types import UNSET, Response, Unset
 
@@ -10,7 +12,6 @@ from ...types import UNSET, Response, Unset
 def _get_kwargs(
     workspace: str,
     *,
-    client: Client,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     order_desc: Union[Unset, None, bool] = UNSET,
@@ -22,13 +23,10 @@ def _get_kwargs(
     parent_hash: Union[Unset, None, str] = UNSET,
     show_archived: Union[Unset, None, bool] = UNSET,
     is_template: Union[Unset, None, bool] = UNSET,
-    kind: Union[Unset, None, str] = UNSET,
+    kinds: Union[Unset, None, str] = UNSET,
     starred_only: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
-    url = "{}/w/{workspace}/scripts/list".format(client.base_url, workspace=workspace)
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
+    pass
 
     params: Dict[str, Any] = {}
     params["page"] = page
@@ -53,7 +51,7 @@ def _get_kwargs(
 
     params["is_template"] = is_template
 
-    params["kind"] = kind
+    params["kinds"] = kinds
 
     params["starred_only"] = starred_only
 
@@ -61,16 +59,17 @@ def _get_kwargs(
 
     return {
         "method": "get",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
+        "url": "/w/{workspace}/scripts/list".format(
+            workspace=workspace,
+        ),
         "params": params,
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[List[ListScriptsResponse200Item]]:
-    if response.status_code == 200:
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[List["ListScriptsResponse200Item"]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = []
         _response_200 = response.json()
         for response_200_item_data in _response_200:
@@ -79,22 +78,27 @@ def _parse_response(*, response: httpx.Response) -> Optional[List[ListScriptsRes
             response_200.append(response_200_item)
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(response.status_code, response.content)
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[List[ListScriptsResponse200Item]]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[List["ListScriptsResponse200Item"]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
 def sync_detailed(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     order_desc: Union[Unset, None, bool] = UNSET,
@@ -106,10 +110,10 @@ def sync_detailed(
     parent_hash: Union[Unset, None, str] = UNSET,
     show_archived: Union[Unset, None, bool] = UNSET,
     is_template: Union[Unset, None, bool] = UNSET,
-    kind: Union[Unset, None, str] = UNSET,
+    kinds: Union[Unset, None, str] = UNSET,
     starred_only: Union[Unset, None, bool] = UNSET,
-) -> Response[List[ListScriptsResponse200Item]]:
-    """list all available scripts
+) -> Response[List["ListScriptsResponse200Item"]]:
+    """list all scripts
 
     Args:
         workspace (str):
@@ -124,16 +128,19 @@ def sync_detailed(
         parent_hash (Union[Unset, None, str]):
         show_archived (Union[Unset, None, bool]):
         is_template (Union[Unset, None, bool]):
-        kind (Union[Unset, None, str]):
+        kinds (Union[Unset, None, str]):
         starred_only (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListScriptsResponse200Item]]
+        Response[List['ListScriptsResponse200Item']]
     """
 
     kwargs = _get_kwargs(
         workspace=workspace,
-        client=client,
         page=page,
         per_page=per_page,
         order_desc=order_desc,
@@ -145,22 +152,21 @@ def sync_detailed(
         parent_hash=parent_hash,
         show_archived=show_archived,
         is_template=is_template,
-        kind=kind,
+        kinds=kinds,
         starred_only=starred_only,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     order_desc: Union[Unset, None, bool] = UNSET,
@@ -172,10 +178,10 @@ def sync(
     parent_hash: Union[Unset, None, str] = UNSET,
     show_archived: Union[Unset, None, bool] = UNSET,
     is_template: Union[Unset, None, bool] = UNSET,
-    kind: Union[Unset, None, str] = UNSET,
+    kinds: Union[Unset, None, str] = UNSET,
     starred_only: Union[Unset, None, bool] = UNSET,
-) -> Optional[List[ListScriptsResponse200Item]]:
-    """list all available scripts
+) -> Optional[List["ListScriptsResponse200Item"]]:
+    """list all scripts
 
     Args:
         workspace (str):
@@ -190,11 +196,15 @@ def sync(
         parent_hash (Union[Unset, None, str]):
         show_archived (Union[Unset, None, bool]):
         is_template (Union[Unset, None, bool]):
-        kind (Union[Unset, None, str]):
+        kinds (Union[Unset, None, str]):
         starred_only (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListScriptsResponse200Item]]
+        List['ListScriptsResponse200Item']
     """
 
     return sync_detailed(
@@ -211,7 +221,7 @@ def sync(
         parent_hash=parent_hash,
         show_archived=show_archived,
         is_template=is_template,
-        kind=kind,
+        kinds=kinds,
         starred_only=starred_only,
     ).parsed
 
@@ -219,7 +229,7 @@ def sync(
 async def asyncio_detailed(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     order_desc: Union[Unset, None, bool] = UNSET,
@@ -231,10 +241,10 @@ async def asyncio_detailed(
     parent_hash: Union[Unset, None, str] = UNSET,
     show_archived: Union[Unset, None, bool] = UNSET,
     is_template: Union[Unset, None, bool] = UNSET,
-    kind: Union[Unset, None, str] = UNSET,
+    kinds: Union[Unset, None, str] = UNSET,
     starred_only: Union[Unset, None, bool] = UNSET,
-) -> Response[List[ListScriptsResponse200Item]]:
-    """list all available scripts
+) -> Response[List["ListScriptsResponse200Item"]]:
+    """list all scripts
 
     Args:
         workspace (str):
@@ -249,16 +259,19 @@ async def asyncio_detailed(
         parent_hash (Union[Unset, None, str]):
         show_archived (Union[Unset, None, bool]):
         is_template (Union[Unset, None, bool]):
-        kind (Union[Unset, None, str]):
+        kinds (Union[Unset, None, str]):
         starred_only (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListScriptsResponse200Item]]
+        Response[List['ListScriptsResponse200Item']]
     """
 
     kwargs = _get_kwargs(
         workspace=workspace,
-        client=client,
         page=page,
         per_page=per_page,
         order_desc=order_desc,
@@ -270,20 +283,19 @@ async def asyncio_detailed(
         parent_hash=parent_hash,
         show_archived=show_archived,
         is_template=is_template,
-        kind=kind,
+        kinds=kinds,
         starred_only=starred_only,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
     workspace: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     order_desc: Union[Unset, None, bool] = UNSET,
@@ -295,10 +307,10 @@ async def asyncio(
     parent_hash: Union[Unset, None, str] = UNSET,
     show_archived: Union[Unset, None, bool] = UNSET,
     is_template: Union[Unset, None, bool] = UNSET,
-    kind: Union[Unset, None, str] = UNSET,
+    kinds: Union[Unset, None, str] = UNSET,
     starred_only: Union[Unset, None, bool] = UNSET,
-) -> Optional[List[ListScriptsResponse200Item]]:
-    """list all available scripts
+) -> Optional[List["ListScriptsResponse200Item"]]:
+    """list all scripts
 
     Args:
         workspace (str):
@@ -313,11 +325,15 @@ async def asyncio(
         parent_hash (Union[Unset, None, str]):
         show_archived (Union[Unset, None, bool]):
         is_template (Union[Unset, None, bool]):
-        kind (Union[Unset, None, str]):
+        kinds (Union[Unset, None, str]):
         starred_only (Union[Unset, None, bool]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[List[ListScriptsResponse200Item]]
+        List['ListScriptsResponse200Item']
     """
 
     return (
@@ -335,7 +351,7 @@ async def asyncio(
             parent_hash=parent_hash,
             show_archived=show_archived,
             is_template=is_template,
-            kind=kind,
+            kinds=kinds,
             starred_only=starred_only,
         )
     ).parsed
