@@ -1,17 +1,21 @@
 import datetime
-from typing import Any, Dict, List, Type, TypeVar, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
 from ..models.app_with_last_version_execution_mode import AppWithLastVersionExecutionMode
-from ..models.app_with_last_version_extra_perms import AppWithLastVersionExtraPerms
-from ..models.app_with_last_version_policy import AppWithLastVersionPolicy
+
+if TYPE_CHECKING:
+    from ..models.app_with_last_version_extra_perms import AppWithLastVersionExtraPerms
+    from ..models.app_with_last_version_policy import AppWithLastVersionPolicy
+
 
 T = TypeVar("T", bound="AppWithLastVersion")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class AppWithLastVersion:
     """
     Attributes:
@@ -36,10 +40,10 @@ class AppWithLastVersion:
     created_by: str
     created_at: datetime.datetime
     value: Any
-    policy: AppWithLastVersionPolicy
+    policy: "AppWithLastVersionPolicy"
     execution_mode: AppWithLastVersionExecutionMode
-    extra_perms: AppWithLastVersionExtraPerms
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    extra_perms: "AppWithLastVersionExtraPerms"
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         id = self.id
@@ -80,6 +84,9 @@ class AppWithLastVersion:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.app_with_last_version_extra_perms import AppWithLastVersionExtraPerms
+        from ..models.app_with_last_version_policy import AppWithLastVersionPolicy
+
         d = src_dict.copy()
         id = d.pop("id")
 
