@@ -1,20 +1,24 @@
 import datetime
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
-from ..models.completed_job_args import CompletedJobArgs
-from ..models.completed_job_flow_status import CompletedJobFlowStatus
 from ..models.completed_job_job_kind import CompletedJobJobKind
 from ..models.completed_job_language import CompletedJobLanguage
-from ..models.completed_job_raw_flow import CompletedJobRawFlow
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.completed_job_args import CompletedJobArgs
+    from ..models.completed_job_flow_status import CompletedJobFlowStatus
+    from ..models.completed_job_raw_flow import CompletedJobRawFlow
+
+
 T = TypeVar("T", bound="CompletedJob")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class CompletedJob:
     """
     Attributes:
@@ -49,6 +53,7 @@ class CompletedJob:
         raw_flow (Union[Unset, CompletedJobRawFlow]):
         language (Union[Unset, CompletedJobLanguage]):
         mem_peak (Union[Unset, int]):
+        priority (Union[Unset, int]):
     """
 
     id: str
@@ -69,7 +74,7 @@ class CompletedJob:
     parent_job: Union[Unset, str] = UNSET
     script_path: Union[Unset, str] = UNSET
     script_hash: Union[Unset, str] = UNSET
-    args: Union[Unset, CompletedJobArgs] = UNSET
+    args: Union[Unset, "CompletedJobArgs"] = UNSET
     result: Union[Unset, Any] = UNSET
     logs: Union[Unset, str] = UNSET
     deleted: Union[Unset, bool] = UNSET
@@ -77,11 +82,12 @@ class CompletedJob:
     canceled_by: Union[Unset, str] = UNSET
     canceled_reason: Union[Unset, str] = UNSET
     schedule_path: Union[Unset, str] = UNSET
-    flow_status: Union[Unset, CompletedJobFlowStatus] = UNSET
-    raw_flow: Union[Unset, CompletedJobRawFlow] = UNSET
+    flow_status: Union[Unset, "CompletedJobFlowStatus"] = UNSET
+    raw_flow: Union[Unset, "CompletedJobRawFlow"] = UNSET
     language: Union[Unset, CompletedJobLanguage] = UNSET
     mem_peak: Union[Unset, int] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    priority: Union[Unset, int] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         id = self.id
@@ -129,6 +135,7 @@ class CompletedJob:
             language = self.language.value
 
         mem_peak = self.mem_peak
+        priority = self.priority
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -182,11 +189,17 @@ class CompletedJob:
             field_dict["language"] = language
         if mem_peak is not UNSET:
             field_dict["mem_peak"] = mem_peak
+        if priority is not UNSET:
+            field_dict["priority"] = priority
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.completed_job_args import CompletedJobArgs
+        from ..models.completed_job_flow_status import CompletedJobFlowStatus
+        from ..models.completed_job_raw_flow import CompletedJobRawFlow
+
         d = src_dict.copy()
         id = d.pop("id")
 
@@ -268,6 +281,8 @@ class CompletedJob:
 
         mem_peak = d.pop("mem_peak", UNSET)
 
+        priority = d.pop("priority", UNSET)
+
         completed_job = cls(
             id=id,
             created_by=created_by,
@@ -299,6 +314,7 @@ class CompletedJob:
             raw_flow=raw_flow,
             language=language,
             mem_peak=mem_peak,
+            priority=priority,
         )
 
         completed_job.additional_properties = d
