@@ -1,15 +1,19 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
 from ..models.create_app_json_body_policy_execution_mode import CreateAppJsonBodyPolicyExecutionMode
-from ..models.create_app_json_body_policy_triggerables import CreateAppJsonBodyPolicyTriggerables
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.create_app_json_body_policy_triggerables import CreateAppJsonBodyPolicyTriggerables
+
+
 T = TypeVar("T", bound="CreateAppJsonBodyPolicy")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class CreateAppJsonBodyPolicy:
     """
     Attributes:
@@ -19,11 +23,11 @@ class CreateAppJsonBodyPolicy:
         on_behalf_of_email (Union[Unset, str]):
     """
 
-    triggerables: Union[Unset, CreateAppJsonBodyPolicyTriggerables] = UNSET
+    triggerables: Union[Unset, "CreateAppJsonBodyPolicyTriggerables"] = UNSET
     execution_mode: Union[Unset, CreateAppJsonBodyPolicyExecutionMode] = UNSET
     on_behalf_of: Union[Unset, str] = UNSET
     on_behalf_of_email: Union[Unset, str] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         triggerables: Union[Unset, Dict[str, Any]] = UNSET
@@ -53,6 +57,8 @@ class CreateAppJsonBodyPolicy:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.create_app_json_body_policy_triggerables import CreateAppJsonBodyPolicyTriggerables
+
         d = src_dict.copy()
         _triggerables = d.pop("triggerables", UNSET)
         triggerables: Union[Unset, CreateAppJsonBodyPolicyTriggerables]
