@@ -1,16 +1,20 @@
-from typing import Any, Dict, List, Type, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
 from ..models.create_script_json_body_kind import CreateScriptJsonBodyKind
 from ..models.create_script_json_body_language import CreateScriptJsonBodyLanguage
-from ..models.create_script_json_body_schema import CreateScriptJsonBodySchema
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.create_script_json_body_schema import CreateScriptJsonBodySchema
+
+
 T = TypeVar("T", bound="CreateScriptJsonBody")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class CreateScriptJsonBody:
     """
     Attributes:
@@ -27,8 +31,16 @@ class CreateScriptJsonBody:
         tag (Union[Unset, str]):
         draft_only (Union[Unset, bool]):
         envs (Union[Unset, List[str]]):
-        concurrent_limit (Union[Unset, List[int]]):
-        concurrency_time_window_s (Union[Unset, List[int]]):
+        concurrent_limit (Union[Unset, int]):
+        concurrency_time_window_s (Union[Unset, int]):
+        cache_ttl (Union[Unset, float]):
+        dedicated_worker (Union[Unset, bool]):
+        ws_error_handler_muted (Union[Unset, bool]):
+        priority (Union[Unset, int]):
+        restart_unless_cancelled (Union[Unset, bool]):
+        timeout (Union[Unset, int]):
+        delete_after_use (Union[Unset, bool]):
+        deployment_message (Union[Unset, str]):
     """
 
     path: str
@@ -37,16 +49,24 @@ class CreateScriptJsonBody:
     content: str
     language: CreateScriptJsonBodyLanguage
     parent_hash: Union[Unset, str] = UNSET
-    schema: Union[Unset, CreateScriptJsonBodySchema] = UNSET
+    schema: Union[Unset, "CreateScriptJsonBodySchema"] = UNSET
     is_template: Union[Unset, bool] = UNSET
     lock: Union[Unset, List[str]] = UNSET
     kind: Union[Unset, CreateScriptJsonBodyKind] = UNSET
     tag: Union[Unset, str] = UNSET
     draft_only: Union[Unset, bool] = UNSET
     envs: Union[Unset, List[str]] = UNSET
-    concurrent_limit: Union[Unset, List[int]] = UNSET
-    concurrency_time_window_s: Union[Unset, List[int]] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    concurrent_limit: Union[Unset, int] = UNSET
+    concurrency_time_window_s: Union[Unset, int] = UNSET
+    cache_ttl: Union[Unset, float] = UNSET
+    dedicated_worker: Union[Unset, bool] = UNSET
+    ws_error_handler_muted: Union[Unset, bool] = UNSET
+    priority: Union[Unset, int] = UNSET
+    restart_unless_cancelled: Union[Unset, bool] = UNSET
+    timeout: Union[Unset, int] = UNSET
+    delete_after_use: Union[Unset, bool] = UNSET
+    deployment_message: Union[Unset, str] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         path = self.path
@@ -75,13 +95,16 @@ class CreateScriptJsonBody:
         if not isinstance(self.envs, Unset):
             envs = self.envs
 
-        concurrent_limit: Union[Unset, List[int]] = UNSET
-        if not isinstance(self.concurrent_limit, Unset):
-            concurrent_limit = self.concurrent_limit
-
-        concurrency_time_window_s: Union[Unset, List[int]] = UNSET
-        if not isinstance(self.concurrency_time_window_s, Unset):
-            concurrency_time_window_s = self.concurrency_time_window_s
+        concurrent_limit = self.concurrent_limit
+        concurrency_time_window_s = self.concurrency_time_window_s
+        cache_ttl = self.cache_ttl
+        dedicated_worker = self.dedicated_worker
+        ws_error_handler_muted = self.ws_error_handler_muted
+        priority = self.priority
+        restart_unless_cancelled = self.restart_unless_cancelled
+        timeout = self.timeout
+        delete_after_use = self.delete_after_use
+        deployment_message = self.deployment_message
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -114,11 +137,29 @@ class CreateScriptJsonBody:
             field_dict["concurrent_limit"] = concurrent_limit
         if concurrency_time_window_s is not UNSET:
             field_dict["concurrency_time_window_s"] = concurrency_time_window_s
+        if cache_ttl is not UNSET:
+            field_dict["cache_ttl"] = cache_ttl
+        if dedicated_worker is not UNSET:
+            field_dict["dedicated_worker"] = dedicated_worker
+        if ws_error_handler_muted is not UNSET:
+            field_dict["ws_error_handler_muted"] = ws_error_handler_muted
+        if priority is not UNSET:
+            field_dict["priority"] = priority
+        if restart_unless_cancelled is not UNSET:
+            field_dict["restart_unless_cancelled"] = restart_unless_cancelled
+        if timeout is not UNSET:
+            field_dict["timeout"] = timeout
+        if delete_after_use is not UNSET:
+            field_dict["delete_after_use"] = delete_after_use
+        if deployment_message is not UNSET:
+            field_dict["deployment_message"] = deployment_message
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.create_script_json_body_schema import CreateScriptJsonBodySchema
+
         d = src_dict.copy()
         path = d.pop("path")
 
@@ -156,9 +197,25 @@ class CreateScriptJsonBody:
 
         envs = cast(List[str], d.pop("envs", UNSET))
 
-        concurrent_limit = cast(List[int], d.pop("concurrent_limit", UNSET))
+        concurrent_limit = d.pop("concurrent_limit", UNSET)
 
-        concurrency_time_window_s = cast(List[int], d.pop("concurrency_time_window_s", UNSET))
+        concurrency_time_window_s = d.pop("concurrency_time_window_s", UNSET)
+
+        cache_ttl = d.pop("cache_ttl", UNSET)
+
+        dedicated_worker = d.pop("dedicated_worker", UNSET)
+
+        ws_error_handler_muted = d.pop("ws_error_handler_muted", UNSET)
+
+        priority = d.pop("priority", UNSET)
+
+        restart_unless_cancelled = d.pop("restart_unless_cancelled", UNSET)
+
+        timeout = d.pop("timeout", UNSET)
+
+        delete_after_use = d.pop("delete_after_use", UNSET)
+
+        deployment_message = d.pop("deployment_message", UNSET)
 
         create_script_json_body = cls(
             path=path,
@@ -176,6 +233,14 @@ class CreateScriptJsonBody:
             envs=envs,
             concurrent_limit=concurrent_limit,
             concurrency_time_window_s=concurrency_time_window_s,
+            cache_ttl=cache_ttl,
+            dedicated_worker=dedicated_worker,
+            ws_error_handler_muted=ws_error_handler_muted,
+            priority=priority,
+            restart_unless_cancelled=restart_unless_cancelled,
+            timeout=timeout,
+            delete_after_use=delete_after_use,
+            deployment_message=deployment_message,
         )
 
         create_script_json_body.additional_properties = d
