@@ -2,14 +2,16 @@ from enum import Enum
 
 
 class DeleteCompletedJobResponse200JobKind(str, Enum):
-    SCRIPT = "script"
-    PREVIEW = "preview"
+    APPDEPENDENCIES = "appdependencies"
     DEPENDENCIES = "dependencies"
+    DEPLOYMENTCALLBACK = "deploymentcallback"
     FLOW = "flow"
+    FLOWDEPENDENCIES = "flowdependencies"
     FLOWPREVIEW = "flowpreview"
-    SCRIPT_HUB = "script_hub"
     IDENTITY = "identity"
-    HTTP = "http"
+    PREVIEW = "preview"
+    SCRIPT = "script"
+    SCRIPT_HUB = "script_hub"
 
     def __str__(self) -> str:
         return str(self.value)
