@@ -1,19 +1,23 @@
 import datetime
-from typing import Any, Dict, List, Type, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
-from ..models.delete_script_by_hash_response_200_extra_perms import DeleteScriptByHashResponse200ExtraPerms
 from ..models.delete_script_by_hash_response_200_kind import DeleteScriptByHashResponse200Kind
 from ..models.delete_script_by_hash_response_200_language import DeleteScriptByHashResponse200Language
-from ..models.delete_script_by_hash_response_200_schema import DeleteScriptByHashResponse200Schema
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.delete_script_by_hash_response_200_extra_perms import DeleteScriptByHashResponse200ExtraPerms
+    from ..models.delete_script_by_hash_response_200_schema import DeleteScriptByHashResponse200Schema
+
+
 T = TypeVar("T", bound="DeleteScriptByHashResponse200")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class DeleteScriptByHashResponse200:
     """
     Attributes:
@@ -41,8 +45,15 @@ class DeleteScriptByHashResponse200:
         has_draft (Union[Unset, bool]):
         draft_only (Union[Unset, bool]):
         envs (Union[Unset, List[str]]):
-        concurrent_limit (Union[Unset, List[int]]):
-        concurrency_time_window_s (Union[Unset, List[int]]):
+        concurrent_limit (Union[Unset, int]):
+        concurrency_time_window_s (Union[Unset, int]):
+        cache_ttl (Union[Unset, float]):
+        dedicated_worker (Union[Unset, bool]):
+        ws_error_handler_muted (Union[Unset, bool]):
+        priority (Union[Unset, int]):
+        restart_unless_cancelled (Union[Unset, bool]):
+        timeout (Union[Unset, int]):
+        delete_after_use (Union[Unset, bool]):
     """
 
     hash_: str
@@ -55,22 +66,29 @@ class DeleteScriptByHashResponse200:
     archived: bool
     deleted: bool
     is_template: bool
-    extra_perms: DeleteScriptByHashResponse200ExtraPerms
+    extra_perms: "DeleteScriptByHashResponse200ExtraPerms"
     language: DeleteScriptByHashResponse200Language
     kind: DeleteScriptByHashResponse200Kind
     starred: bool
     workspace_id: Union[Unset, str] = UNSET
     parent_hashes: Union[Unset, List[str]] = UNSET
-    schema: Union[Unset, DeleteScriptByHashResponse200Schema] = UNSET
+    schema: Union[Unset, "DeleteScriptByHashResponse200Schema"] = UNSET
     lock: Union[Unset, str] = UNSET
     lock_error_logs: Union[Unset, str] = UNSET
     tag: Union[Unset, str] = UNSET
     has_draft: Union[Unset, bool] = UNSET
     draft_only: Union[Unset, bool] = UNSET
     envs: Union[Unset, List[str]] = UNSET
-    concurrent_limit: Union[Unset, List[int]] = UNSET
-    concurrency_time_window_s: Union[Unset, List[int]] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    concurrent_limit: Union[Unset, int] = UNSET
+    concurrency_time_window_s: Union[Unset, int] = UNSET
+    cache_ttl: Union[Unset, float] = UNSET
+    dedicated_worker: Union[Unset, bool] = UNSET
+    ws_error_handler_muted: Union[Unset, bool] = UNSET
+    priority: Union[Unset, int] = UNSET
+    restart_unless_cancelled: Union[Unset, bool] = UNSET
+    timeout: Union[Unset, int] = UNSET
+    delete_after_use: Union[Unset, bool] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         hash_ = self.hash_
@@ -109,13 +127,15 @@ class DeleteScriptByHashResponse200:
         if not isinstance(self.envs, Unset):
             envs = self.envs
 
-        concurrent_limit: Union[Unset, List[int]] = UNSET
-        if not isinstance(self.concurrent_limit, Unset):
-            concurrent_limit = self.concurrent_limit
-
-        concurrency_time_window_s: Union[Unset, List[int]] = UNSET
-        if not isinstance(self.concurrency_time_window_s, Unset):
-            concurrency_time_window_s = self.concurrency_time_window_s
+        concurrent_limit = self.concurrent_limit
+        concurrency_time_window_s = self.concurrency_time_window_s
+        cache_ttl = self.cache_ttl
+        dedicated_worker = self.dedicated_worker
+        ws_error_handler_muted = self.ws_error_handler_muted
+        priority = self.priority
+        restart_unless_cancelled = self.restart_unless_cancelled
+        timeout = self.timeout
+        delete_after_use = self.delete_after_use
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -159,11 +179,28 @@ class DeleteScriptByHashResponse200:
             field_dict["concurrent_limit"] = concurrent_limit
         if concurrency_time_window_s is not UNSET:
             field_dict["concurrency_time_window_s"] = concurrency_time_window_s
+        if cache_ttl is not UNSET:
+            field_dict["cache_ttl"] = cache_ttl
+        if dedicated_worker is not UNSET:
+            field_dict["dedicated_worker"] = dedicated_worker
+        if ws_error_handler_muted is not UNSET:
+            field_dict["ws_error_handler_muted"] = ws_error_handler_muted
+        if priority is not UNSET:
+            field_dict["priority"] = priority
+        if restart_unless_cancelled is not UNSET:
+            field_dict["restart_unless_cancelled"] = restart_unless_cancelled
+        if timeout is not UNSET:
+            field_dict["timeout"] = timeout
+        if delete_after_use is not UNSET:
+            field_dict["delete_after_use"] = delete_after_use
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.delete_script_by_hash_response_200_extra_perms import DeleteScriptByHashResponse200ExtraPerms
+        from ..models.delete_script_by_hash_response_200_schema import DeleteScriptByHashResponse200Schema
+
         d = src_dict.copy()
         hash_ = d.pop("hash")
 
@@ -216,9 +253,23 @@ class DeleteScriptByHashResponse200:
 
         envs = cast(List[str], d.pop("envs", UNSET))
 
-        concurrent_limit = cast(List[int], d.pop("concurrent_limit", UNSET))
+        concurrent_limit = d.pop("concurrent_limit", UNSET)
 
-        concurrency_time_window_s = cast(List[int], d.pop("concurrency_time_window_s", UNSET))
+        concurrency_time_window_s = d.pop("concurrency_time_window_s", UNSET)
+
+        cache_ttl = d.pop("cache_ttl", UNSET)
+
+        dedicated_worker = d.pop("dedicated_worker", UNSET)
+
+        ws_error_handler_muted = d.pop("ws_error_handler_muted", UNSET)
+
+        priority = d.pop("priority", UNSET)
+
+        restart_unless_cancelled = d.pop("restart_unless_cancelled", UNSET)
+
+        timeout = d.pop("timeout", UNSET)
+
+        delete_after_use = d.pop("delete_after_use", UNSET)
 
         delete_script_by_hash_response_200 = cls(
             hash_=hash_,
@@ -246,6 +297,13 @@ class DeleteScriptByHashResponse200:
             envs=envs,
             concurrent_limit=concurrent_limit,
             concurrency_time_window_s=concurrency_time_window_s,
+            cache_ttl=cache_ttl,
+            dedicated_worker=dedicated_worker,
+            ws_error_handler_muted=ws_error_handler_muted,
+            priority=priority,
+            restart_unless_cancelled=restart_unless_cancelled,
+            timeout=timeout,
+            delete_after_use=delete_after_use,
         )
 
         delete_script_by_hash_response_200.additional_properties = d
