@@ -1,17 +1,21 @@
 import datetime
-from typing import Any, Dict, List, Type, TypeVar, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
 from ..models.get_app_by_version_response_200_execution_mode import GetAppByVersionResponse200ExecutionMode
-from ..models.get_app_by_version_response_200_extra_perms import GetAppByVersionResponse200ExtraPerms
-from ..models.get_app_by_version_response_200_policy import GetAppByVersionResponse200Policy
+
+if TYPE_CHECKING:
+    from ..models.get_app_by_version_response_200_extra_perms import GetAppByVersionResponse200ExtraPerms
+    from ..models.get_app_by_version_response_200_policy import GetAppByVersionResponse200Policy
+
 
 T = TypeVar("T", bound="GetAppByVersionResponse200")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class GetAppByVersionResponse200:
     """
     Attributes:
@@ -36,10 +40,10 @@ class GetAppByVersionResponse200:
     created_by: str
     created_at: datetime.datetime
     value: Any
-    policy: GetAppByVersionResponse200Policy
+    policy: "GetAppByVersionResponse200Policy"
     execution_mode: GetAppByVersionResponse200ExecutionMode
-    extra_perms: GetAppByVersionResponse200ExtraPerms
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    extra_perms: "GetAppByVersionResponse200ExtraPerms"
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         id = self.id
@@ -80,6 +84,9 @@ class GetAppByVersionResponse200:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.get_app_by_version_response_200_extra_perms import GetAppByVersionResponse200ExtraPerms
+        from ..models.get_app_by_version_response_200_policy import GetAppByVersionResponse200Policy
+
         d = src_dict.copy()
         id = d.pop("id")
 
