@@ -1,20 +1,24 @@
 import datetime
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
-from ..models.get_completed_job_response_200_args import GetCompletedJobResponse200Args
-from ..models.get_completed_job_response_200_flow_status import GetCompletedJobResponse200FlowStatus
 from ..models.get_completed_job_response_200_job_kind import GetCompletedJobResponse200JobKind
 from ..models.get_completed_job_response_200_language import GetCompletedJobResponse200Language
-from ..models.get_completed_job_response_200_raw_flow import GetCompletedJobResponse200RawFlow
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.get_completed_job_response_200_args import GetCompletedJobResponse200Args
+    from ..models.get_completed_job_response_200_flow_status import GetCompletedJobResponse200FlowStatus
+    from ..models.get_completed_job_response_200_raw_flow import GetCompletedJobResponse200RawFlow
+
+
 T = TypeVar("T", bound="GetCompletedJobResponse200")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class GetCompletedJobResponse200:
     """
     Attributes:
@@ -49,6 +53,7 @@ class GetCompletedJobResponse200:
         raw_flow (Union[Unset, GetCompletedJobResponse200RawFlow]):
         language (Union[Unset, GetCompletedJobResponse200Language]):
         mem_peak (Union[Unset, int]):
+        priority (Union[Unset, int]):
     """
 
     id: str
@@ -69,7 +74,7 @@ class GetCompletedJobResponse200:
     parent_job: Union[Unset, str] = UNSET
     script_path: Union[Unset, str] = UNSET
     script_hash: Union[Unset, str] = UNSET
-    args: Union[Unset, GetCompletedJobResponse200Args] = UNSET
+    args: Union[Unset, "GetCompletedJobResponse200Args"] = UNSET
     result: Union[Unset, Any] = UNSET
     logs: Union[Unset, str] = UNSET
     deleted: Union[Unset, bool] = UNSET
@@ -77,11 +82,12 @@ class GetCompletedJobResponse200:
     canceled_by: Union[Unset, str] = UNSET
     canceled_reason: Union[Unset, str] = UNSET
     schedule_path: Union[Unset, str] = UNSET
-    flow_status: Union[Unset, GetCompletedJobResponse200FlowStatus] = UNSET
-    raw_flow: Union[Unset, GetCompletedJobResponse200RawFlow] = UNSET
+    flow_status: Union[Unset, "GetCompletedJobResponse200FlowStatus"] = UNSET
+    raw_flow: Union[Unset, "GetCompletedJobResponse200RawFlow"] = UNSET
     language: Union[Unset, GetCompletedJobResponse200Language] = UNSET
     mem_peak: Union[Unset, int] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    priority: Union[Unset, int] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         id = self.id
@@ -129,6 +135,7 @@ class GetCompletedJobResponse200:
             language = self.language.value
 
         mem_peak = self.mem_peak
+        priority = self.priority
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -182,11 +189,17 @@ class GetCompletedJobResponse200:
             field_dict["language"] = language
         if mem_peak is not UNSET:
             field_dict["mem_peak"] = mem_peak
+        if priority is not UNSET:
+            field_dict["priority"] = priority
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.get_completed_job_response_200_args import GetCompletedJobResponse200Args
+        from ..models.get_completed_job_response_200_flow_status import GetCompletedJobResponse200FlowStatus
+        from ..models.get_completed_job_response_200_raw_flow import GetCompletedJobResponse200RawFlow
+
         d = src_dict.copy()
         id = d.pop("id")
 
@@ -268,6 +281,8 @@ class GetCompletedJobResponse200:
 
         mem_peak = d.pop("mem_peak", UNSET)
 
+        priority = d.pop("priority", UNSET)
+
         get_completed_job_response_200 = cls(
             id=id,
             created_by=created_by,
@@ -299,6 +314,7 @@ class GetCompletedJobResponse200:
             raw_flow=raw_flow,
             language=language,
             mem_peak=mem_peak,
+            priority=priority,
         )
 
         get_completed_job_response_200.additional_properties = d
