@@ -1,18 +1,22 @@
 import datetime
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
-from ..models.get_flow_by_path_response_200_extra_perms import GetFlowByPathResponse200ExtraPerms
-from ..models.get_flow_by_path_response_200_schema import GetFlowByPathResponse200Schema
-from ..models.get_flow_by_path_response_200_value import GetFlowByPathResponse200Value
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.get_flow_by_path_response_200_extra_perms import GetFlowByPathResponse200ExtraPerms
+    from ..models.get_flow_by_path_response_200_schema import GetFlowByPathResponse200Schema
+    from ..models.get_flow_by_path_response_200_value import GetFlowByPathResponse200Value
+
+
 T = TypeVar("T", bound="GetFlowByPathResponse200")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class GetFlowByPathResponse200:
     """
     Attributes:
@@ -29,22 +33,32 @@ class GetFlowByPathResponse200:
         additional_properties (Union[Unset, bool]):
         starred (Union[Unset, bool]):
         draft_only (Union[Unset, bool]):
+        tag (Union[Unset, str]):
+        ws_error_handler_muted (Union[Unset, bool]):
+        priority (Union[Unset, int]):
+        dedicated_worker (Union[Unset, bool]):
+        timeout (Union[Unset, float]):
     """
 
     summary: str
-    value: GetFlowByPathResponse200Value
+    value: "GetFlowByPathResponse200Value"
     path: str
     edited_by: str
     edited_at: datetime.datetime
     archived: bool
-    extra_perms: GetFlowByPathResponse200ExtraPerms
+    extra_perms: "GetFlowByPathResponse200ExtraPerms"
     description: Union[Unset, str] = UNSET
-    schema: Union[Unset, GetFlowByPathResponse200Schema] = UNSET
+    schema: Union[Unset, "GetFlowByPathResponse200Schema"] = UNSET
     workspace_id: Union[Unset, str] = UNSET
     additional_properties: Union[Unset, bool] = UNSET
     starred: Union[Unset, bool] = UNSET
     draft_only: Union[Unset, bool] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    tag: Union[Unset, str] = UNSET
+    ws_error_handler_muted: Union[Unset, bool] = UNSET
+    priority: Union[Unset, int] = UNSET
+    dedicated_worker: Union[Unset, bool] = UNSET
+    timeout: Union[Unset, float] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         summary = self.summary
@@ -66,6 +80,11 @@ class GetFlowByPathResponse200:
         additional_properties = self.additional_properties
         starred = self.starred
         draft_only = self.draft_only
+        tag = self.tag
+        ws_error_handler_muted = self.ws_error_handler_muted
+        priority = self.priority
+        dedicated_worker = self.dedicated_worker
+        timeout = self.timeout
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -92,11 +111,25 @@ class GetFlowByPathResponse200:
             field_dict["starred"] = starred
         if draft_only is not UNSET:
             field_dict["draft_only"] = draft_only
+        if tag is not UNSET:
+            field_dict["tag"] = tag
+        if ws_error_handler_muted is not UNSET:
+            field_dict["ws_error_handler_muted"] = ws_error_handler_muted
+        if priority is not UNSET:
+            field_dict["priority"] = priority
+        if dedicated_worker is not UNSET:
+            field_dict["dedicated_worker"] = dedicated_worker
+        if timeout is not UNSET:
+            field_dict["timeout"] = timeout
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.get_flow_by_path_response_200_extra_perms import GetFlowByPathResponse200ExtraPerms
+        from ..models.get_flow_by_path_response_200_schema import GetFlowByPathResponse200Schema
+        from ..models.get_flow_by_path_response_200_value import GetFlowByPathResponse200Value
+
         d = src_dict.copy()
         summary = d.pop("summary")
 
@@ -129,6 +162,16 @@ class GetFlowByPathResponse200:
 
         draft_only = d.pop("draft_only", UNSET)
 
+        tag = d.pop("tag", UNSET)
+
+        ws_error_handler_muted = d.pop("ws_error_handler_muted", UNSET)
+
+        priority = d.pop("priority", UNSET)
+
+        dedicated_worker = d.pop("dedicated_worker", UNSET)
+
+        timeout = d.pop("timeout", UNSET)
+
         get_flow_by_path_response_200 = cls(
             summary=summary,
             value=value,
@@ -143,6 +186,11 @@ class GetFlowByPathResponse200:
             additional_properties=additional_properties,
             starred=starred,
             draft_only=draft_only,
+            tag=tag,
+            ws_error_handler_muted=ws_error_handler_muted,
+            priority=priority,
+            dedicated_worker=dedicated_worker,
+            timeout=timeout,
         )
 
         get_flow_by_path_response_200.additional_properties = d
