@@ -2,15 +2,19 @@ from enum import Enum
 
 
 class GetScriptByPathWithDraftResponse200Language(str, Enum):
-    PYTHON3 = "python3"
+    BASH = "bash"
+    BIGQUERY = "bigquery"
+    BUN = "bun"
     DENO = "deno"
     GO = "go"
-    BASH = "bash"
-    POSTGRESQL = "postgresql"
-    MYSQL = "mysql"
     GRAPHQL = "graphql"
+    MSSQL = "mssql"
+    MYSQL = "mysql"
     NATIVETS = "nativets"
-    BUN = "bun"
+    POSTGRESQL = "postgresql"
+    POWERSHELL = "powershell"
+    PYTHON3 = "python3"
+    SNOWFLAKE = "snowflake"
 
     def __str__(self) -> str:
         return str(self.value)
