@@ -1,62 +1,76 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_mock import (
-    ListCompletedJobsResponse200ItemRawFlowFailureModuleMock,
-)
-from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_retry import (
-    ListCompletedJobsResponse200ItemRawFlowFailureModuleRetry,
-)
-from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_sleep_type_0 import (
-    ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType0,
-)
-from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_sleep_type_1 import (
-    ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType1,
-)
-from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_stop_after_if import (
-    ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterIf,
-)
-from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_suspend import (
-    ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspend,
-)
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_mock import (
+        ListCompletedJobsResponse200ItemRawFlowFailureModuleMock,
+    )
+    from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_retry import (
+        ListCompletedJobsResponse200ItemRawFlowFailureModuleRetry,
+    )
+    from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_sleep_type_0 import (
+        ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType0,
+    )
+    from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_sleep_type_1 import (
+        ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType1,
+    )
+    from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_stop_after_if import (
+        ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterIf,
+    )
+    from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_suspend import (
+        ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspend,
+    )
+
+
 T = TypeVar("T", bound="ListCompletedJobsResponse200ItemRawFlowFailureModule")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class ListCompletedJobsResponse200ItemRawFlowFailureModule:
     """
     Attributes:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterIf]):
-        sleep (Union[ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType0,
-            ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType1, Unset]):
+        sleep (Union['ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType0',
+            'ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
+        timeout (Union[Unset, float]):
+        delete_after_use (Union[Unset, bool]):
         summary (Union[Unset, str]):
         mock (Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleMock]):
         suspend (Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspend]):
+        priority (Union[Unset, float]):
         retry (Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleRetry]):
     """
 
     id: str
     value: Any
-    stop_after_if: Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterIf] = UNSET
+    stop_after_if: Union[Unset, "ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterIf"] = UNSET
     sleep: Union[
-        ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType0,
-        ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType1,
+        "ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType0",
+        "ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType1",
         Unset,
     ] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
+    timeout: Union[Unset, float] = UNSET
+    delete_after_use: Union[Unset, bool] = UNSET
     summary: Union[Unset, str] = UNSET
-    mock: Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleMock] = UNSET
-    suspend: Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspend] = UNSET
-    retry: Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleRetry] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    mock: Union[Unset, "ListCompletedJobsResponse200ItemRawFlowFailureModuleMock"] = UNSET
+    suspend: Union[Unset, "ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspend"] = UNSET
+    priority: Union[Unset, float] = UNSET
+    retry: Union[Unset, "ListCompletedJobsResponse200ItemRawFlowFailureModuleRetry"] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_sleep_type_0 import (
+            ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType0,
+        )
+
         id = self.id
         value = self.value
         stop_after_if: Union[Unset, Dict[str, Any]] = UNSET
@@ -78,6 +92,8 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
                 sleep = self.sleep.to_dict()
 
         cache_ttl = self.cache_ttl
+        timeout = self.timeout
+        delete_after_use = self.delete_after_use
         summary = self.summary
         mock: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.mock, Unset):
@@ -87,6 +103,7 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
         if not isinstance(self.suspend, Unset):
             suspend = self.suspend.to_dict()
 
+        priority = self.priority
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
             retry = self.retry.to_dict()
@@ -105,12 +122,18 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
             field_dict["cache_ttl"] = cache_ttl
+        if timeout is not UNSET:
+            field_dict["timeout"] = timeout
+        if delete_after_use is not UNSET:
+            field_dict["delete_after_use"] = delete_after_use
         if summary is not UNSET:
             field_dict["summary"] = summary
         if mock is not UNSET:
             field_dict["mock"] = mock
         if suspend is not UNSET:
             field_dict["suspend"] = suspend
+        if priority is not UNSET:
+            field_dict["priority"] = priority
         if retry is not UNSET:
             field_dict["retry"] = retry
 
@@ -118,6 +141,25 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_mock import (
+            ListCompletedJobsResponse200ItemRawFlowFailureModuleMock,
+        )
+        from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_retry import (
+            ListCompletedJobsResponse200ItemRawFlowFailureModuleRetry,
+        )
+        from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_sleep_type_0 import (
+            ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType0,
+        )
+        from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_sleep_type_1 import (
+            ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType1,
+        )
+        from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_stop_after_if import (
+            ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterIf,
+        )
+        from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_suspend import (
+            ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspend,
+        )
+
         d = src_dict.copy()
         id = d.pop("id")
 
@@ -133,8 +175,8 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
         def _parse_sleep(
             data: object,
         ) -> Union[
-            ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType0,
-            ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType1,
+            "ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType0",
+            "ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType1",
             Unset,
         ]:
             if isinstance(data, Unset):
@@ -169,6 +211,10 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
+        timeout = d.pop("timeout", UNSET)
+
+        delete_after_use = d.pop("delete_after_use", UNSET)
+
         summary = d.pop("summary", UNSET)
 
         _mock = d.pop("mock", UNSET)
@@ -185,6 +231,8 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
         else:
             suspend = ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspend.from_dict(_suspend)
 
+        priority = d.pop("priority", UNSET)
+
         _retry = d.pop("retry", UNSET)
         retry: Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleRetry]
         if isinstance(_retry, Unset):
@@ -198,9 +246,12 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
             stop_after_if=stop_after_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
+            timeout=timeout,
+            delete_after_use=delete_after_use,
             summary=summary,
             mock=mock,
             suspend=suspend,
+            priority=priority,
             retry=retry,
         )
 
