@@ -1,14 +1,18 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.listable_resource_extra_perms import ListableResourceExtraPerms
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.listable_resource_extra_perms import ListableResourceExtraPerms
+
+
 T = TypeVar("T", bound="ListableResource")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class ListableResource:
     """
     Attributes:
@@ -34,11 +38,11 @@ class ListableResource:
     workspace_id: Union[Unset, str] = UNSET
     description: Union[Unset, str] = UNSET
     value: Union[Unset, Any] = UNSET
-    extra_perms: Union[Unset, ListableResourceExtraPerms] = UNSET
+    extra_perms: Union[Unset, "ListableResourceExtraPerms"] = UNSET
     is_expired: Union[Unset, bool] = UNSET
     refresh_error: Union[Unset, str] = UNSET
     account: Union[Unset, float] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         path = self.path
@@ -87,6 +91,8 @@ class ListableResource:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.listable_resource_extra_perms import ListableResourceExtraPerms
+
         d = src_dict.copy()
         path = d.pop("path")
 
