@@ -1,17 +1,21 @@
-from typing import Any, Dict, List, Type, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.new_script_with_draft_draft import NewScriptWithDraftDraft
 from ..models.new_script_with_draft_kind import NewScriptWithDraftKind
 from ..models.new_script_with_draft_language import NewScriptWithDraftLanguage
-from ..models.new_script_with_draft_schema import NewScriptWithDraftSchema
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.new_script_with_draft_draft import NewScriptWithDraftDraft
+    from ..models.new_script_with_draft_schema import NewScriptWithDraftSchema
+
+
 T = TypeVar("T", bound="NewScriptWithDraft")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class NewScriptWithDraft:
     """
     Attributes:
@@ -29,8 +33,16 @@ class NewScriptWithDraft:
         tag (Union[Unset, str]):
         draft_only (Union[Unset, bool]):
         envs (Union[Unset, List[str]]):
-        concurrent_limit (Union[Unset, List[int]]):
-        concurrency_time_window_s (Union[Unset, List[int]]):
+        concurrent_limit (Union[Unset, int]):
+        concurrency_time_window_s (Union[Unset, int]):
+        cache_ttl (Union[Unset, float]):
+        dedicated_worker (Union[Unset, bool]):
+        ws_error_handler_muted (Union[Unset, bool]):
+        priority (Union[Unset, int]):
+        restart_unless_cancelled (Union[Unset, bool]):
+        timeout (Union[Unset, int]):
+        delete_after_use (Union[Unset, bool]):
+        deployment_message (Union[Unset, str]):
         draft (Union[Unset, NewScriptWithDraftDraft]):
     """
 
@@ -41,17 +53,25 @@ class NewScriptWithDraft:
     language: NewScriptWithDraftLanguage
     hash_: str
     parent_hash: Union[Unset, str] = UNSET
-    schema: Union[Unset, NewScriptWithDraftSchema] = UNSET
+    schema: Union[Unset, "NewScriptWithDraftSchema"] = UNSET
     is_template: Union[Unset, bool] = UNSET
     lock: Union[Unset, List[str]] = UNSET
     kind: Union[Unset, NewScriptWithDraftKind] = UNSET
     tag: Union[Unset, str] = UNSET
     draft_only: Union[Unset, bool] = UNSET
     envs: Union[Unset, List[str]] = UNSET
-    concurrent_limit: Union[Unset, List[int]] = UNSET
-    concurrency_time_window_s: Union[Unset, List[int]] = UNSET
-    draft: Union[Unset, NewScriptWithDraftDraft] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    concurrent_limit: Union[Unset, int] = UNSET
+    concurrency_time_window_s: Union[Unset, int] = UNSET
+    cache_ttl: Union[Unset, float] = UNSET
+    dedicated_worker: Union[Unset, bool] = UNSET
+    ws_error_handler_muted: Union[Unset, bool] = UNSET
+    priority: Union[Unset, int] = UNSET
+    restart_unless_cancelled: Union[Unset, bool] = UNSET
+    timeout: Union[Unset, int] = UNSET
+    delete_after_use: Union[Unset, bool] = UNSET
+    deployment_message: Union[Unset, str] = UNSET
+    draft: Union[Unset, "NewScriptWithDraftDraft"] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         path = self.path
@@ -81,14 +101,16 @@ class NewScriptWithDraft:
         if not isinstance(self.envs, Unset):
             envs = self.envs
 
-        concurrent_limit: Union[Unset, List[int]] = UNSET
-        if not isinstance(self.concurrent_limit, Unset):
-            concurrent_limit = self.concurrent_limit
-
-        concurrency_time_window_s: Union[Unset, List[int]] = UNSET
-        if not isinstance(self.concurrency_time_window_s, Unset):
-            concurrency_time_window_s = self.concurrency_time_window_s
-
+        concurrent_limit = self.concurrent_limit
+        concurrency_time_window_s = self.concurrency_time_window_s
+        cache_ttl = self.cache_ttl
+        dedicated_worker = self.dedicated_worker
+        ws_error_handler_muted = self.ws_error_handler_muted
+        priority = self.priority
+        restart_unless_cancelled = self.restart_unless_cancelled
+        timeout = self.timeout
+        delete_after_use = self.delete_after_use
+        deployment_message = self.deployment_message
         draft: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.draft, Unset):
             draft = self.draft.to_dict()
@@ -125,6 +147,22 @@ class NewScriptWithDraft:
             field_dict["concurrent_limit"] = concurrent_limit
         if concurrency_time_window_s is not UNSET:
             field_dict["concurrency_time_window_s"] = concurrency_time_window_s
+        if cache_ttl is not UNSET:
+            field_dict["cache_ttl"] = cache_ttl
+        if dedicated_worker is not UNSET:
+            field_dict["dedicated_worker"] = dedicated_worker
+        if ws_error_handler_muted is not UNSET:
+            field_dict["ws_error_handler_muted"] = ws_error_handler_muted
+        if priority is not UNSET:
+            field_dict["priority"] = priority
+        if restart_unless_cancelled is not UNSET:
+            field_dict["restart_unless_cancelled"] = restart_unless_cancelled
+        if timeout is not UNSET:
+            field_dict["timeout"] = timeout
+        if delete_after_use is not UNSET:
+            field_dict["delete_after_use"] = delete_after_use
+        if deployment_message is not UNSET:
+            field_dict["deployment_message"] = deployment_message
         if draft is not UNSET:
             field_dict["draft"] = draft
 
@@ -132,6 +170,9 @@ class NewScriptWithDraft:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.new_script_with_draft_draft import NewScriptWithDraftDraft
+        from ..models.new_script_with_draft_schema import NewScriptWithDraftSchema
+
         d = src_dict.copy()
         path = d.pop("path")
 
@@ -171,9 +212,25 @@ class NewScriptWithDraft:
 
         envs = cast(List[str], d.pop("envs", UNSET))
 
-        concurrent_limit = cast(List[int], d.pop("concurrent_limit", UNSET))
+        concurrent_limit = d.pop("concurrent_limit", UNSET)
 
-        concurrency_time_window_s = cast(List[int], d.pop("concurrency_time_window_s", UNSET))
+        concurrency_time_window_s = d.pop("concurrency_time_window_s", UNSET)
+
+        cache_ttl = d.pop("cache_ttl", UNSET)
+
+        dedicated_worker = d.pop("dedicated_worker", UNSET)
+
+        ws_error_handler_muted = d.pop("ws_error_handler_muted", UNSET)
+
+        priority = d.pop("priority", UNSET)
+
+        restart_unless_cancelled = d.pop("restart_unless_cancelled", UNSET)
+
+        timeout = d.pop("timeout", UNSET)
+
+        delete_after_use = d.pop("delete_after_use", UNSET)
+
+        deployment_message = d.pop("deployment_message", UNSET)
 
         _draft = d.pop("draft", UNSET)
         draft: Union[Unset, NewScriptWithDraftDraft]
@@ -199,6 +256,14 @@ class NewScriptWithDraft:
             envs=envs,
             concurrent_limit=concurrent_limit,
             concurrency_time_window_s=concurrency_time_window_s,
+            cache_ttl=cache_ttl,
+            dedicated_worker=dedicated_worker,
+            ws_error_handler_muted=ws_error_handler_muted,
+            priority=priority,
+            restart_unless_cancelled=restart_unless_cancelled,
+            timeout=timeout,
+            delete_after_use=delete_after_use,
+            deployment_message=deployment_message,
             draft=draft,
         )
 
