@@ -1,15 +1,19 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.path_script_input_transforms import PathScriptInputTransforms
 from ..models.path_script_type import PathScriptType
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.path_script_input_transforms import PathScriptInputTransforms
+
+
 T = TypeVar("T", bound="PathScript")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class PathScript:
     """
     Attributes:
@@ -19,11 +23,11 @@ class PathScript:
         hash_ (Union[Unset, str]):
     """
 
-    input_transforms: PathScriptInputTransforms
+    input_transforms: "PathScriptInputTransforms"
     path: str
     type: PathScriptType
     hash_: Union[Unset, str] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         input_transforms = self.input_transforms.to_dict()
@@ -49,6 +53,8 @@ class PathScript:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.path_script_input_transforms import PathScriptInputTransforms
+
         d = src_dict.copy()
         input_transforms = PathScriptInputTransforms.from_dict(d.pop("input_transforms"))
 
