@@ -1,15 +1,19 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
 from ..models.policy_execution_mode import PolicyExecutionMode
-from ..models.policy_triggerables import PolicyTriggerables
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.policy_triggerables import PolicyTriggerables
+
+
 T = TypeVar("T", bound="Policy")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class Policy:
     """
     Attributes:
@@ -19,11 +23,11 @@ class Policy:
         on_behalf_of_email (Union[Unset, str]):
     """
 
-    triggerables: Union[Unset, PolicyTriggerables] = UNSET
+    triggerables: Union[Unset, "PolicyTriggerables"] = UNSET
     execution_mode: Union[Unset, PolicyExecutionMode] = UNSET
     on_behalf_of: Union[Unset, str] = UNSET
     on_behalf_of_email: Union[Unset, str] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         triggerables: Union[Unset, Dict[str, Any]] = UNSET
@@ -53,6 +57,8 @@ class Policy:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.policy_triggerables import PolicyTriggerables
+
         d = src_dict.copy()
         _triggerables = d.pop("triggerables", UNSET)
         triggerables: Union[Unset, PolicyTriggerables]
