@@ -1,16 +1,20 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.preview_args import PreviewArgs
 from ..models.preview_kind import PreviewKind
 from ..models.preview_language import PreviewLanguage
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.preview_args import PreviewArgs
+
+
 T = TypeVar("T", bound="Preview")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class Preview:
     """
     Attributes:
@@ -20,15 +24,17 @@ class Preview:
         language (Union[Unset, PreviewLanguage]):
         tag (Union[Unset, str]):
         kind (Union[Unset, PreviewKind]):
+        dedicated_worker (Union[Unset, bool]):
     """
 
-    args: PreviewArgs
+    args: "PreviewArgs"
     content: Union[Unset, str] = UNSET
     path: Union[Unset, str] = UNSET
     language: Union[Unset, PreviewLanguage] = UNSET
     tag: Union[Unset, str] = UNSET
     kind: Union[Unset, PreviewKind] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    dedicated_worker: Union[Unset, bool] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         args = self.args.to_dict()
@@ -44,6 +50,8 @@ class Preview:
         if not isinstance(self.kind, Unset):
             kind = self.kind.value
 
+        dedicated_worker = self.dedicated_worker
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -61,11 +69,15 @@ class Preview:
             field_dict["tag"] = tag
         if kind is not UNSET:
             field_dict["kind"] = kind
+        if dedicated_worker is not UNSET:
+            field_dict["dedicated_worker"] = dedicated_worker
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.preview_args import PreviewArgs
+
         d = src_dict.copy()
         args = PreviewArgs.from_dict(d.pop("args"))
 
@@ -89,6 +101,8 @@ class Preview:
         else:
             kind = PreviewKind(_kind)
 
+        dedicated_worker = d.pop("dedicated_worker", UNSET)
+
         preview = cls(
             args=args,
             content=content,
@@ -96,6 +110,7 @@ class Preview:
             language=language,
             tag=tag,
             kind=kind,
+            dedicated_worker=dedicated_worker,
         )
 
         preview.additional_properties = d
